# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudrouter/v1/routing_instance_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudrouter/v1/routing_instance_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.cloudrouter.v1 import routing_instance_pb2 as yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/cloudrouter/v1/routing_instance_service.proto\x12\x1byandex.cloud.cloudrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/cloudrouter/v1/routing_instance.proto\"F\n\x19GetRoutingInstanceRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"d\n1GetRoutingInstanceByCicPrivateConnectionIdRequest\x12/\n\x19\x63ic_private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"O\n\'GetRoutingInstanceByVpcNetworkIdRequest\x12$\n\x0evpc_network_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1bListRoutingInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x80\x01\n\x1cListRoutingInstancesResponse\x12G\n\x11routing_instances\x18\x01 \x03(\x0b\x32,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xeb\x03\n\x1c\x43reateRoutingInstanceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x05 \x01(\t\x12\x46\n\x08vpc_info\x18\x06 \x03(\x0b\x32\x34.yandex.cloud.cloudrouter.v1.RoutingInstance.VpcInfo\x12j\n\x1b\x63ic_private_connection_info\x18\x07 \x03(\x0b\x32\x45.yandex.cloud.cloudrouter.v1.RoutingInstance.CicPrivateConnectionInfo\x12\x92\x01\n\x06labels\x18\x0c \x03(\x0b\x32\x45.yandex.cloud.cloudrouter.v1.CreateRoutingInstanceRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x08\x10\x0c\"<\n\x1d\x43reateRoutingInstanceMetadata\x12\x1b\n\x13routing_instance_id\x18\x01 \x01(\t\"\xb4\x04\n\x1cUpdateRoutingInstanceRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12\x46\n\x08vpc_info\x18\x08 \x03(\x0b\x32\x34.yandex.cloud.cloudrouter.v1.RoutingInstance.VpcInfo\x12j\n\x1b\x63ic_private_connection_info\x18\t \x03(\x0b\x32\x45.yandex.cloud.cloudrouter.v1.RoutingInstance.CicPrivateConnectionInfo\x12\x92\x01\n\x06labels\x18\x0e \x03(\x0b\x32\x45.yandex.cloud.cloudrouter.v1.UpdateRoutingInstanceRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x07J\x04\x08\n\x10\x0e\"<\n\x1dUpdateRoutingInstanceMetadata\x12\x1b\n\x13routing_instance_id\x18\x01 \x01(\t\"\xae\x01\n\x15UpsertPrefixesRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0evpc_network_id\x18\x02 \x01(\t\x12L\n\x14vpc_az_info_prefixes\x18\x03 \x03(\x0b\x32..yandex.cloud.cloudrouter.v1.VpcAzInfoPrefixesJ\x04\x08\x04\x10\x07\"\xa8\x01\n\x15RemovePrefixesRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0evpc_network_id\x18\x02 \x01(\t\x12L\n\x14vpc_az_info_prefixes\x18\x03 \x03(\x0b\x32..yandex.cloud.cloudrouter.v1.VpcAzInfoPrefixes\":\n\x11VpcAzInfoPrefixes\x12\r\n\x05\x61z_id\x18\x01 \x01(\t\x12\x10\n\x08prefixes\x18\x02 \x03(\tJ\x04\x08\x03\x10\x04\"q\n\x1b\x41\x64\x64PrivateConnectionRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x19\x63ic_private_connection_id\x18\x02 \x01(\tJ\x04\x08\x03\x10\t\"n\n\x1eRemovePrivateConnectionRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x19\x63ic_private_connection_id\x18\x02 \x01(\t\"I\n\x1c\x44\x65leteRoutingInstanceRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x44\x65leteRoutingInstanceMetadata\x12\x1b\n\x13routing_instance_id\x18\x01 \x01(\t\"x\n$ListRoutingInstanceOperationsRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n%ListRoutingInstanceOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe3\x13\n\x16RoutingInstanceService\x12\xab\x01\n\x03Get\x12\x36.yandex.cloud.cloudrouter.v1.GetRoutingInstanceRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cloudrouter/v1/routingInstances/{routing_instance_id}\x12\x87\x01\n\x11GetByVpcNetworkId\x12\x44.yandex.cloud.cloudrouter.v1.GetRoutingInstanceByVpcNetworkIdRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x9b\x01\n\x1bGetByCicPrivateConnectionId\x12N.yandex.cloud.cloudrouter.v1.GetRoutingInstanceByCicPrivateConnectionIdRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\xa5\x01\n\x04List\x12\x38.yandex.cloud.cloudrouter.v1.ListRoutingInstancesRequest\x1a\x39.yandex.cloud.cloudrouter.v1.ListRoutingInstancesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cloudrouter/v1/routingInstances\x12\xc7\x01\n\x06\x43reate\x12\x39.yandex.cloud.cloudrouter.v1.CreateRoutingInstanceRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*0\n\x1d\x43reateRoutingInstanceMetadata\x12\x0fRoutingInstance\x82\xd3\xe4\x93\x02%\" /cloudrouter/v1/routingInstances:\x01*\x12\xc7\x01\n\x06Update\x12\x39.yandex.cloud.cloudrouter.v1.UpdateRoutingInstanceRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*0\n\x1dUpdateRoutingInstanceMetadata\x12\x0fRoutingInstance\x82\xd3\xe4\x93\x02%2 /cloudrouter/v1/routingInstances:\x01*\x12\xee\x01\n\x0eUpsertPrefixes\x12\x32.yandex.cloud.cloudrouter.v1.UpsertPrefixesRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*0\n\x1dUpdateRoutingInstanceMetadata\x12\x0fRoutingInstance\x82\xd3\xe4\x93\x02J\"E/cloudrouter/v1/routingInstances/{routing_instance_id}:upsertPrefixes:\x01*\x12\xee\x01\n\x0eRemovePrefixes\x12\x32.yandex.cloud.cloudrouter.v1.RemovePrefixesRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*0\n\x1dUpdateRoutingInstanceMetadata\x12\x0fRoutingInstance\x82\xd3\xe4\x93\x02J\"E/cloudrouter/v1/routingInstances/{routing_instance_id}:removePrefixes:\x01*\x12\x80\x02\n\x14\x41\x64\x64PrivateConnection\x12\x38.yandex.cloud.cloudrouter.v1.AddPrivateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"\x8a\x01\xb2\xd2*0\n\x1dUpdateRoutingInstanceMetadata\x12\x0fRoutingInstance\x82\xd3\xe4\x93\x02P\"K/cloudrouter/v1/routingInstances/{routing_instance_id}:addPrivateConnection:\x01*\x12\x89\x02\n\x17RemovePrivateConnection\x12;.yandex.cloud.cloudrouter.v1.RemovePrivateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*0\n\x1dUpdateRoutingInstanceMetadata\x12\x0fRoutingInstance\x82\xd3\xe4\x93\x02S\"N/cloudrouter/v1/routingInstances/{routing_instance_id}:removePrivateConnection:\x01*\x12\xe0\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.cloudrouter.v1.DeleteRoutingInstanceRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*6\n\x1d\x44\x65leteRoutingInstanceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x38*6/cloudrouter/v1/routingInstances/{routing_instance_id}\x12\xe2\x01\n\x0eListOperations\x12\x41.yandex.cloud.cloudrouter.v1.ListRoutingInstanceOperationsRequest\x1a\x42.yandex.cloud.cloudrouter.v1.ListRoutingInstanceOperationsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/cloudrouter/v1/routingInstances/{routing_instance_id}/operationsBn\n\x1fyandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudrouter.v1.routing_instance_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouter'
  _globals['_GETROUTINGINSTANCEREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_GETROUTINGINSTANCEREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST'].fields_by_name['cic_private_connection_id']._loaded_options = None
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST'].fields_by_name['cic_private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST'].fields_by_name['vpc_network_id']._loaded_options = None
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST'].fields_by_name['vpc_network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTROUTINGINSTANCESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEROUTINGINSTANCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEROUTINGINSTANCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEROUTINGINSTANCEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEROUTINGINSTANCEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEROUTINGINSTANCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEROUTINGINSTANCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEROUTINGINSTANCEREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_UPDATEROUTINGINSTANCEREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEROUTINGINSTANCEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEROUTINGINSTANCEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPSERTPREFIXESREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_UPSERTPREFIXESREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REMOVEPREFIXESREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_REMOVEPREFIXESREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDPRIVATECONNECTIONREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_ADDPRIVATECONNECTIONREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REMOVEPRIVATECONNECTIONREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_REMOVEPRIVATECONNECTIONREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEROUTINGINSTANCEREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_DELETEROUTINGINSTANCEREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROUTINGINSTANCEOPERATIONSREQUEST'].fields_by_name['routing_instance_id']._loaded_options = None
  _globals['_LISTROUTINGINSTANCEOPERATIONSREQUEST'].fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0028\0226/cloudrouter/v1/routingInstances/{routing_instance_id}'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /cloudrouter/v1/routingInstances'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateRoutingInstanceMetadata\022\017RoutingInstance\202\323\344\223\002%\" /cloudrouter/v1/routingInstances:\001*'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateRoutingInstanceMetadata\022\017RoutingInstance\202\323\344\223\002%2 /cloudrouter/v1/routingInstances:\001*'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['UpsertPrefixes']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['UpsertPrefixes']._serialized_options = b'\262\322*0\n\035UpdateRoutingInstanceMetadata\022\017RoutingInstance\202\323\344\223\002J\"E/cloudrouter/v1/routingInstances/{routing_instance_id}:upsertPrefixes:\001*'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['RemovePrefixes']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['RemovePrefixes']._serialized_options = b'\262\322*0\n\035UpdateRoutingInstanceMetadata\022\017RoutingInstance\202\323\344\223\002J\"E/cloudrouter/v1/routingInstances/{routing_instance_id}:removePrefixes:\001*'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['AddPrivateConnection']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['AddPrivateConnection']._serialized_options = b'\262\322*0\n\035UpdateRoutingInstanceMetadata\022\017RoutingInstance\202\323\344\223\002P\"K/cloudrouter/v1/routingInstances/{routing_instance_id}:addPrivateConnection:\001*'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['RemovePrivateConnection']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['RemovePrivateConnection']._serialized_options = b'\262\322*0\n\035UpdateRoutingInstanceMetadata\022\017RoutingInstance\202\323\344\223\002S\"N/cloudrouter/v1/routingInstances/{routing_instance_id}:removePrivateConnection:\001*'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteRoutingInstanceMetadata\022\025google.protobuf.Empty\202\323\344\223\0028*6/cloudrouter/v1/routingInstances/{routing_instance_id}'
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_ROUTINGINSTANCESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002C\022A/cloudrouter/v1/routingInstances/{routing_instance_id}/operations'
  _globals['_GETROUTINGINSTANCEREQUEST']._serialized_start=312
  _globals['_GETROUTINGINSTANCEREQUEST']._serialized_end=382
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST']._serialized_start=384
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST']._serialized_end=484
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST']._serialized_start=486
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST']._serialized_end=565
  _globals['_LISTROUTINGINSTANCESREQUEST']._serialized_start=568
  _globals['_LISTROUTINGINSTANCESREQUEST']._serialized_end=720
  _globals['_LISTROUTINGINSTANCESRESPONSE']._serialized_start=723
  _globals['_LISTROUTINGINSTANCESRESPONSE']._serialized_end=851
  _globals['_CREATEROUTINGINSTANCEREQUEST']._serialized_start=854
  _globals['_CREATEROUTINGINSTANCEREQUEST']._serialized_end=1345
  _globals['_CREATEROUTINGINSTANCEREQUEST_LABELSENTRY']._serialized_start=1288
  _globals['_CREATEROUTINGINSTANCEREQUEST_LABELSENTRY']._serialized_end=1333
  _globals['_CREATEROUTINGINSTANCEMETADATA']._serialized_start=1347
  _globals['_CREATEROUTINGINSTANCEMETADATA']._serialized_end=1407
  _globals['_UPDATEROUTINGINSTANCEREQUEST']._serialized_start=1410
  _globals['_UPDATEROUTINGINSTANCEREQUEST']._serialized_end=1974
  _globals['_UPDATEROUTINGINSTANCEREQUEST_LABELSENTRY']._serialized_start=1288
  _globals['_UPDATEROUTINGINSTANCEREQUEST_LABELSENTRY']._serialized_end=1333
  _globals['_UPDATEROUTINGINSTANCEMETADATA']._serialized_start=1976
  _globals['_UPDATEROUTINGINSTANCEMETADATA']._serialized_end=2036
  _globals['_UPSERTPREFIXESREQUEST']._serialized_start=2039
  _globals['_UPSERTPREFIXESREQUEST']._serialized_end=2213
  _globals['_REMOVEPREFIXESREQUEST']._serialized_start=2216
  _globals['_REMOVEPREFIXESREQUEST']._serialized_end=2384
  _globals['_VPCAZINFOPREFIXES']._serialized_start=2386
  _globals['_VPCAZINFOPREFIXES']._serialized_end=2444
  _globals['_ADDPRIVATECONNECTIONREQUEST']._serialized_start=2446
  _globals['_ADDPRIVATECONNECTIONREQUEST']._serialized_end=2559
  _globals['_REMOVEPRIVATECONNECTIONREQUEST']._serialized_start=2561
  _globals['_REMOVEPRIVATECONNECTIONREQUEST']._serialized_end=2671
  _globals['_DELETEROUTINGINSTANCEREQUEST']._serialized_start=2673
  _globals['_DELETEROUTINGINSTANCEREQUEST']._serialized_end=2746
  _globals['_DELETEROUTINGINSTANCEMETADATA']._serialized_start=2748
  _globals['_DELETEROUTINGINSTANCEMETADATA']._serialized_end=2808
  _globals['_LISTROUTINGINSTANCEOPERATIONSREQUEST']._serialized_start=2810
  _globals['_LISTROUTINGINSTANCEOPERATIONSREQUEST']._serialized_end=2930
  _globals['_LISTROUTINGINSTANCEOPERATIONSRESPONSE']._serialized_start=2932
  _globals['_LISTROUTINGINSTANCEOPERATIONSRESPONSE']._serialized_end=3051
  _globals['_ROUTINGINSTANCESERVICE']._serialized_start=3054
  _globals['_ROUTINGINSTANCESERVICE']._serialized_end=5585
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/reserved_instance_pool.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/reserved_instance_pool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/compute/v1/reserved_instance_pool.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a.yandex/cloud/compute/v1/instance_service.proto\x1a\x1dyandex/cloud/validation.proto\"+\n\nProductIDs\x12\x1d\n\x0bproduct_ids\x18\x01 \x03(\tB\x08\x8a\xc8\x31\x04<=50\"\xbb\x01\n\x0c\x42ootDiskSpec\x12\x1b\n\x07\x64isk_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1c\n\x08image_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12:\n\x0bproduct_ids\x18\x04 \x01(\x0b\x32#.yandex.cloud.compute.v1.ProductIDsH\x00\x42\x13\n\x0b\x62oot_source\x12\x04\xc0\xc1\x31\x01\"\x9d\x04\n\x14ReservedInstancePool\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07zone_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12I\n\x06labels\x18\x07 \x03(\x0b\x32\x39.yandex.cloud.compute.v1.ReservedInstancePool.LabelsEntry\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bplatform_id\x18\t \x01(\t\x12>\n\x0eresources_spec\x18\n \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpec\x12:\n\x0cgpu_settings\x18\x0b \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12\x13\n\x0bproduct_ids\x18\x0c \x03(\t\x12\x42\n\x10network_settings\x18\r \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x0c\n\x04size\x18\x0e \x01(\x03\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.reserved_instance_pool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_PRODUCTIDS'].fields_by_name['product_ids']._loaded_options = None
  _globals['_PRODUCTIDS'].fields_by_name['product_ids']._serialized_options = b'\212\3101\004<=50'
  _globals['_BOOTDISKSPEC'].oneofs_by_name['boot_source']._loaded_options = None
  _globals['_BOOTDISKSPEC'].oneofs_by_name['boot_source']._serialized_options = b'\300\3011\001'
  _globals['_BOOTDISKSPEC'].fields_by_name['disk_id']._loaded_options = None
  _globals['_BOOTDISKSPEC'].fields_by_name['disk_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_BOOTDISKSPEC'].fields_by_name['image_id']._loaded_options = None
  _globals['_BOOTDISKSPEC'].fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_BOOTDISKSPEC'].fields_by_name['snapshot_id']._loaded_options = None
  _globals['_BOOTDISKSPEC'].fields_by_name['snapshot_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PRODUCTIDS']._serialized_start=233
  _globals['_PRODUCTIDS']._serialized_end=276
  _globals['_BOOTDISKSPEC']._serialized_start=279
  _globals['_BOOTDISKSPEC']._serialized_end=466
  _globals['_RESERVEDINSTANCEPOOL']._serialized_start=469
  _globals['_RESERVEDINSTANCEPOOL']._serialized_end=1010
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._serialized_start=965
  _globals['_RESERVEDINSTANCEPOOL_LABELSENTRY']._serialized_end=1010
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/logging/v1/log_resource.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/logging/v1/log_resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/logging/v1/log_resource.proto\x12\x17yandex.cloud.logging.v1\x1a\x1dyandex/cloud/validation.proto\"@\n\x10LogEntryResource\x12\x16\n\x04type\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=63\x12\x14\n\x02id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=63\"-\n\x10LogGroupResource\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03ids\x18\x02 \x03(\tBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _globals['_LOGENTRYRESOURCE'].fields_by_name['type']._loaded_options = None
  _globals['_LOGENTRYRESOURCE'].fields_by_name['type']._serialized_options = b'\212\3101\004<=63'
  _globals['_LOGENTRYRESOURCE'].fields_by_name['id']._loaded_options = None
  _globals['_LOGENTRYRESOURCE'].fields_by_name['id']._serialized_options = b'\212\3101\004<=63'
  _globals['_LOGENTRYRESOURCE']._serialized_start=102
  _globals['_LOGENTRYRESOURCE']._serialized_end=166
  _globals['_LOGGROUPRESOURCE']._serialized_start=168
  _globals['_LOGGROUPRESOURCE']._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartwebsecurity/v1/security_profile.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartwebsecurity/v1/security_profile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/smartwebsecurity/v1/security_profile.proto\x12 yandex.cloud.smartwebsecurity.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x86\x08\n\x0fSecurityProfile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x8a\x01\n\x06labels\x18\x03 \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.SecurityProfile.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x04name\x18\x04 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12]\n\x0e\x64\x65\x66\x61ult_action\x18\x06 \x01(\x0e\x32?.yandex.cloud.smartwebsecurity.v1.SecurityProfile.DefaultActionB\x04\xe8\xc7\x31\x01\x12\x46\n\x0esecurity_rules\x18\x07 \x03(\x0b\x32..yandex.cloud.smartwebsecurity.v1.SecurityRule\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x63loud_id\x18\n \x01(\t\x12\x12\n\ncaptcha_id\x18\x0b \x01(\t\x12(\n advanced_rate_limiter_profile_id\x18\x0c \x01(\t\x12\x62\n\x14\x61nalyze_request_body\x18\r \x01(\x0b\x32\x44.yandex.cloud.smartwebsecurity.v1.SecurityProfile.AnalyzeRequestBody\x1a\xe6\x01\n\x12\x41nalyzeRequestBody\x12\x30\n\nsize_limit\x18\x01 \x01(\x03\x42\x1c\xfa\xc7\x31\x18\x30,8,16,32,64,128,256,512\x12\x66\n\x11size_limit_action\x18\x02 \x01(\x0e\x32K.yandex.cloud.smartwebsecurity.v1.SecurityProfile.AnalyzeRequestBody.Action\"6\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\n\n\x06IGNORE\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\rDefaultAction\x12\x1e\n\x1a\x44\x45\x46\x41ULT_ACTION_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02J\x04\x08\t\x10\n\"\xb6\x08\n\x0cSecurityRule\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x08priority\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x31-999999\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12V\n\x0erule_condition\x18\x04 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.SecurityRule.RuleConditionH\x00\x12Z\n\x10smart_protection\x18\x05 \x01(\x0b\x32>.yandex.cloud.smartwebsecurity.v1.SecurityRule.SmartProtectionH\x00\x12\x41\n\x03waf\x18\x06 \x01(\x0b\x32\x32.yandex.cloud.smartwebsecurity.v1.SecurityRule.WafH\x00\x12\x1e\n\x0b\x64\x65scription\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a\xdb\x01\n\rRuleCondition\x12S\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x43.yandex.cloud.smartwebsecurity.v1.SecurityRule.RuleCondition.Action\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\x1a\xd5\x01\n\x0fSmartProtection\x12Q\n\x04mode\x18\x01 \x01(\x0e\x32\x43.yandex.cloud.smartwebsecurity.v1.SecurityRule.SmartProtection.Mode\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\"/\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x07\n\x03\x41PI\x10\x02\x1a\xdb\x01\n\x03Waf\x12\x45\n\x04mode\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.smartwebsecurity.v1.SecurityRule.Waf.Mode\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\x12\x1c\n\x0ewaf_profile_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x07\n\x03\x41PI\x10\x02\x42\x10\n\x0erule_specifier\"\xf9\r\n\tCondition\x12O\n\tauthority\x18\x01 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.Condition.AuthorityMatcher\x12R\n\x0bhttp_method\x18\x02 \x01(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.Condition.HttpMethodMatcher\x12R\n\x0brequest_uri\x18\x03 \x01(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.Condition.RequestUriMatcher\x12T\n\x07headers\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.HeaderMatcherB\x08\x82\xc8\x31\x04<=20\x12H\n\tsource_ip\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.smartwebsecurity.v1.Condition.IpMatcher\x1a\xfc\x01\n\rStringMatcher\x12 \n\x0b\x65xact_match\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12$\n\x0f\x65xact_not_match\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12!\n\x0cprefix_match\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10prefix_not_match\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10pire_regex_match\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12)\n\x14pire_regex_not_match\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x42\x07\n\x05match\x1an\n\x11HttpMethodMatcher\x12Y\n\x0chttp_methods\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x08\x82\xc8\x31\x04<=20\x1al\n\x10\x41uthorityMatcher\x12X\n\x0b\x61uthorities\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x08\x82\xc8\x31\x04<=20\x1a\xb1\x01\n\x11RequestUriMatcher\x12G\n\x04path\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcher\x12S\n\x07queries\x18\x02 \x03(\x0b\x32\x38.yandex.cloud.smartwebsecurity.v1.Condition.QueryMatcherB\x08\x82\xc8\x31\x04<=20\x1az\n\x0cQueryMatcher\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1a|\n\rHeaderMatcher\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1a\xdf\x02\n\tIpMatcher\x12T\n\x0fip_ranges_match\x18\x01 \x01(\x0b\x32;.yandex.cloud.smartwebsecurity.v1.Condition.IpRangesMatcher\x12X\n\x13ip_ranges_not_match\x18\x02 \x01(\x0b\x32;.yandex.cloud.smartwebsecurity.v1.Condition.IpRangesMatcher\x12N\n\x0cgeo_ip_match\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.smartwebsecurity.v1.Condition.GeoIpMatcher\x12R\n\x10geo_ip_not_match\x18\x04 \x01(\x0b\x32\x38.yandex.cloud.smartwebsecurity.v1.Condition.GeoIpMatcher\x1a\x31\n\x0fIpRangesMatcher\x12\x1e\n\tip_ranges\x18\x01 \x03(\tB\x0b\x82\xc8\x31\x07<=10000\x1a\x33\n\x0cGeoIpMatcher\x12#\n\tlocations\x18\x01 \x03(\tB\x10\x82\xc8\x31\x03>=1\x8a\xc8\x31\x01\x32\x90\xc8\x31\x01\x42}\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.security_profile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurity'
  _globals['_SECURITYPROFILE_ANALYZEREQUESTBODY'].fields_by_name['size_limit']._loaded_options = None
  _globals['_SECURITYPROFILE_ANALYZEREQUESTBODY'].fields_by_name['size_limit']._serialized_options = b'\372\3071\0300,8,16,32,64,128,256,512'
  _globals['_SECURITYPROFILE_LABELSENTRY']._loaded_options = None
  _globals['_SECURITYPROFILE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYPROFILE'].fields_by_name['labels']._loaded_options = None
  _globals['_SECURITYPROFILE'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_SECURITYPROFILE'].fields_by_name['name']._loaded_options = None
  _globals['_SECURITYPROFILE'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _globals['_SECURITYPROFILE'].fields_by_name['description']._loaded_options = None
  _globals['_SECURITYPROFILE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _globals['_SECURITYPROFILE'].fields_by_name['default_action']._loaded_options = None
  _globals['_SECURITYPROFILE'].fields_by_name['default_action']._serialized_options = b'\350\3071\001'
  _globals['_SECURITYRULE_WAF'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_SECURITYRULE_WAF'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_SECURITYRULE'].fields_by_name['name']._loaded_options = None
  _globals['_SECURITYRULE'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _globals['_SECURITYRULE'].fields_by_name['priority']._loaded_options = None
  _globals['_SECURITYRULE'].fields_by_name['priority']._serialized_options = b'\372\3071\0101-999999'
  _globals['_SECURITYRULE'].fields_by_name['description']._loaded_options = None
  _globals['_SECURITYRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['exact_match']._loaded_options = None
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['exact_match']._serialized_options = b'\212\3101\0050-255'
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['exact_not_match']._loaded_options = None
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['exact_not_match']._serialized_options = b'\212\3101\0050-255'
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['prefix_match']._loaded_options = None
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['prefix_match']._serialized_options = b'\212\3101\0050-255'
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['prefix_not_match']._loaded_options = None
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['prefix_not_match']._serialized_options = b'\212\3101\0050-255'
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['pire_regex_match']._loaded_options = None
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['pire_regex_match']._serialized_options = b'\212\3101\0050-255'
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['pire_regex_not_match']._loaded_options = None
  _globals['_CONDITION_STRINGMATCHER'].fields_by_name['pire_regex_not_match']._serialized_options = b'\212\3101\0050-255'
  _globals['_CONDITION_HTTPMETHODMATCHER'].fields_by_name['http_methods']._loaded_options = None
  _globals['_CONDITION_HTTPMETHODMATCHER'].fields_by_name['http_methods']._serialized_options = b'\202\3101\004<=20'
  _globals['_CONDITION_AUTHORITYMATCHER'].fields_by_name['authorities']._loaded_options = None
  _globals['_CONDITION_AUTHORITYMATCHER'].fields_by_name['authorities']._serialized_options = b'\202\3101\004<=20'
  _globals['_CONDITION_REQUESTURIMATCHER'].fields_by_name['queries']._loaded_options = None
  _globals['_CONDITION_REQUESTURIMATCHER'].fields_by_name['queries']._serialized_options = b'\202\3101\004<=20'
  _globals['_CONDITION_QUERYMATCHER'].fields_by_name['key']._loaded_options = None
  _globals['_CONDITION_QUERYMATCHER'].fields_by_name['key']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _globals['_CONDITION_QUERYMATCHER'].fields_by_name['value']._loaded_options = None
  _globals['_CONDITION_QUERYMATCHER'].fields_by_name['value']._serialized_options = b'\350\3071\001'
  _globals['_CONDITION_HEADERMATCHER'].fields_by_name['name']._loaded_options = None
  _globals['_CONDITION_HEADERMATCHER'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _globals['_CONDITION_HEADERMATCHER'].fields_by_name['value']._loaded_options = None
  _globals['_CONDITION_HEADERMATCHER'].fields_by_name['value']._serialized_options = b'\350\3071\001'
  _globals['_CONDITION_IPRANGESMATCHER'].fields_by_name['ip_ranges']._loaded_options = None
  _globals['_CONDITION_IPRANGESMATCHER'].fields_by_name['ip_ranges']._serialized_options = b'\202\3101\007<=10000'
  _globals['_CONDITION_GEOIPMATCHER'].fields_by_name['locations']._loaded_options = None
  _globals['_CONDITION_GEOIPMATCHER'].fields_by_name['locations']._serialized_options = b'\202\3101\003>=1\212\3101\0012\220\3101\001'
  _globals['_CONDITION'].fields_by_name['headers']._loaded_options = None
  _globals['_CONDITION'].fields_by_name['headers']._serialized_options = b'\202\3101\004<=20'
  _globals['_SECURITYPROFILE']._serialized_start=158
  _globals['_SECURITYPROFILE']._serialized_end=1188
  _globals['_SECURITYPROFILE_ANALYZEREQUESTBODY']._serialized_start=835
  _globals['_SECURITYPROFILE_ANALYZEREQUESTBODY']._serialized_end=1065
  _globals['_SECURITYPROFILE_ANALYZEREQUESTBODY_ACTION']._serialized_start=1011
  _globals['_SECURITYPROFILE_ANALYZEREQUESTBODY_ACTION']._serialized_end=1065
  _globals['_SECURITYPROFILE_LABELSENTRY']._serialized_start=1067
  _globals['_SECURITYPROFILE_LABELSENTRY']._serialized_end=1112
  _globals['_SECURITYPROFILE_DEFAULTACTION']._serialized_start=1114
  _globals['_SECURITYPROFILE_DEFAULTACTION']._serialized_end=1182
  _globals['_SECURITYRULE']._serialized_start=1191
  _globals['_SECURITYRULE']._serialized_end=2269
  _globals['_SECURITYRULE_RULECONDITION']._serialized_start=1594
  _globals['_SECURITYRULE_RULECONDITION']._serialized_end=1813
  _globals['_SECURITYRULE_RULECONDITION_ACTION']._serialized_start=1760
  _globals['_SECURITYRULE_RULECONDITION_ACTION']._serialized_end=1813
  _globals['_SECURITYRULE_SMARTPROTECTION']._serialized_start=1816
  _globals['_SECURITYRULE_SMARTPROTECTION']._serialized_end=2029
  _globals['_SECURITYRULE_SMARTPROTECTION_MODE']._serialized_start=1982
  _globals['_SECURITYRULE_SMARTPROTECTION_MODE']._serialized_end=2029
  _globals['_SECURITYRULE_WAF']._serialized_start=2032
  _globals['_SECURITYRULE_WAF']._serialized_end=2251
  _globals['_SECURITYRULE_WAF_MODE']._serialized_start=1982
  _globals['_SECURITYRULE_WAF_MODE']._serialized_end=2029
  _globals['_CONDITION']._serialized_start=2272
  _globals['_CONDITION']._serialized_end=4057
  _globals['_CONDITION_STRINGMATCHER']._serialized_start=2695
  _globals['_CONDITION_STRINGMATCHER']._serialized_end=2947
  _globals['_CONDITION_HTTPMETHODMATCHER']._serialized_start=2949
  _globals['_CONDITION_HTTPMETHODMATCHER']._serialized_end=3059
  _globals['_CONDITION_AUTHORITYMATCHER']._serialized_start=3061
  _globals['_CONDITION_AUTHORITYMATCHER']._serialized_end=3169
  _globals['_CONDITION_REQUESTURIMATCHER']._serialized_start=3172
  _globals['_CONDITION_REQUESTURIMATCHER']._serialized_end=3349
  _globals['_CONDITION_QUERYMATCHER']._serialized_start=3351
  _globals['_CONDITION_QUERYMATCHER']._serialized_end=3473
  _globals['_CONDITION_HEADERMATCHER']._serialized_start=3475
  _globals['_CONDITION_HEADERMATCHER']._serialized_end=3599
  _globals['_CONDITION_IPMATCHER']._serialized_start=3602
  _globals['_CONDITION_IPMATCHER']._serialized_end=3953
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_start=3955
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_end=4004
  _globals['_CONDITION_GEOIPMATCHER']._serialized_start=4006
  _globals['_CONDITION_GEOIPMATCHER']._serialized_end=4057
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xbc\x17\n\x1aMongodConfig6_0_enterprise\x12W\n\x07storage\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage\x12n\n\x13operation_profiling\x18\x02 \x01(\x0b\x32Q.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling\x12S\n\x03net\x18\x03 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network\x12Y\n\x08security\x18\x04 \x01(\x0b\x32G.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security\x12Z\n\taudit_log\x18\x05 \x01(\x0b\x32G.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.AuditLog\x12\x62\n\rset_parameter\x18\x06 \x01(\x0b\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.SetParameter\x1a\x97\x08\n\x07Storage\x12\x66\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32Q.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger\x12_\n\x07journal\x18\x02 \x01(\x0b\x32N.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.Journal\x1a\xf6\x05\n\nWiredTiger\x12u\n\rengine_config\x18\x01 \x01(\x0b\x32^.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.EngineConfig\x12}\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig\x12s\n\x0cindex_config\x18\x03 \x01(\x0b\x32].yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.IndexConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xf0\x01\n\x10\x43ollectionConfig\x12\x87\x01\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32m.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1a\x45\n\x0bIndexConfig\x12\x36\n\x12prefix_compression\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xbb\x02\n\x12OperationProfiling\x12\x64\n\x04mode\x18\x01 \x01(\x0e\x32V.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x42\n\x13slow_op_sample_rate\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x07\xfa\xc7\x31\x03\x30-1\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1a\xa4\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12g\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32R.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network.Compression\x1a\xe2\x01\n\x0b\x43ompression\x12{\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32].yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\x1a\xad\x02\n\x08Security\x12\x35\n\x11\x65nable_encryption\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12Z\n\x04kmip\x18\x02 \x01(\x0b\x32L.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP\x1a\x8d\x01\n\x04KMIP\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12)\n\x04port\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x11\n\tserver_ca\x18\x03 \x01(\t\x12\x1a\n\x12\x63lient_certificate\x18\x04 \x01(\t\x12\x16\n\x0ekey_identifier\x18\x05 \x01(\t\x1aU\n\x08\x41uditLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x39\n\x15runtime_configuration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xde\x01\n\x0cSetParameter\x12?\n\x1b\x61udit_authorization_success\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13\x65nable_flow_control\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n&min_snapshot_history_window_in_seconds\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"\xd9\x07\n\x1cMongoCfgConfig6_0_enterprise\x12Y\n\x07storage\x18\x01 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage\x12p\n\x13operation_profiling\x18\x02 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling\x12U\n\x03net\x18\x03 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Network\x1a\xc0\x02\n\x07Storage\x12h\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger\x1a\xca\x01\n\nWiredTiger\x12w\n\rengine_config\x18\x01 \x01(\x0b\x32`.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger.EngineConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xf9\x01\n\x12OperationProfiling\x12\x66\n\x04mode\x18\x01 \x01(\x0e\x32X.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\x98\x04\n\x1aMongosConfig6_0_enterprise\x12S\n\x03net\x18\x03 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network\x1a\xa4\x03\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12g\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32R.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network.Compression\x1a\xe2\x01\n\x0b\x43ompression\x12{\n\x0b\x63ompressors\x18\x01 \x03(\x0e\x32].yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network.Compression.CompressorB\x07\x82\xc8\x31\x03\x31-3\"V\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\n\n\x06SNAPPY\x10\x01\x12\x08\n\x04ZLIB\x10\x02\x12\x08\n\x04ZSTD\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"\xa6\x02\n\x1dMongodConfigSet6_0_enterprise\x12X\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\x12S\n\x0buser_config\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\x12V\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\"\xae\x02\n\x1fMongoCfgConfigSet6_0_enterprise\x12Z\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\x12U\n\x0buser_config\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\x12X\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\"\xa6\x02\n\x1dMongosConfigSet6_0_enterprise\x12X\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise\x12S\n\x0buser_config\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise\x12V\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterpriseBx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb'
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL'].fields_by_name['commit_interval']._loaded_options = None
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL'].fields_by_name['commit_interval']._serialized_options = b'\372\3071\0051-500'
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._loaded_options = None
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING'].fields_by_name['slow_op_sample_rate']._loaded_options = None
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING'].fields_by_name['slow_op_sample_rate']._serialized_options = b'\372\3071\0030-1'
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER'].fields_by_name['min_snapshot_history_window_in_seconds']._loaded_options = None
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER'].fields_by_name['min_snapshot_history_window_in_seconds']._serialized_options = b'\372\3071\003>=0'
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._loaded_options = None
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING'].fields_by_name['slow_op_threshold']._serialized_options = b'\372\3071\002>0'
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION'].fields_by_name['compressors']._loaded_options = None
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION'].fields_by_name['compressors']._serialized_options = b'\202\3101\0031-3'
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK'].fields_by_name['max_incoming_connections']._loaded_options = None
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK'].fields_by_name['max_incoming_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MONGODCONFIG6_0_ENTERPRISE']._serialized_start=166
  _globals['_MONGODCONFIG6_0_ENTERPRISE']._serialized_end=3170
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE']._serialized_start=766
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE']._serialized_end=1813
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER']._serialized_start=979
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER']._serialized_end=1737
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=1356
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=1423
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_start=1426
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG']._serialized_end=1666
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_start=1584
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR']._serialized_end=1666
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_start=1668
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_INDEXCONFIG']._serialized_end=1737
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL']._serialized_start=1739
  _globals['_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL']._serialized_end=1813
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING']._serialized_start=1816
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING']._serialized_end=2131
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE']._serialized_start=2072
  _globals['_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE']._serialized_end=2131
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK']._serialized_start=2134
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK']._serialized_end=2554
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION']._serialized_start=2328
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION']._serialized_end=2554
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2468
  _globals['_MONGODCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2554
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SECURITY']._serialized_start=2557
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SECURITY']._serialized_end=2858
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP']._serialized_start=2717
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP']._serialized_end=2858
  _globals['_MONGODCONFIG6_0_ENTERPRISE_AUDITLOG']._serialized_start=2860
  _globals['_MONGODCONFIG6_0_ENTERPRISE_AUDITLOG']._serialized_end=2945
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER']._serialized_start=2948
  _globals['_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER']._serialized_end=3170
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE']._serialized_start=3173
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE']._serialized_end=4158
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE']._serialized_start=3498
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE']._serialized_end=3818
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER']._serialized_start=3616
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER']._serialized_end=3818
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_start=1356
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG']._serialized_end=1423
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING']._serialized_start=3821
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING']._serialized_end=4070
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE']._serialized_start=2072
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE']._serialized_end=2131
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK']._serialized_start=2134
  _globals['_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK']._serialized_end=2220
  _globals['_MONGOSCONFIG6_0_ENTERPRISE']._serialized_start=4161
  _globals['_MONGOSCONFIG6_0_ENTERPRISE']._serialized_end=4697
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK']._serialized_start=4277
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK']._serialized_end=4697
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION']._serialized_start=4471
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION']._serialized_end=4697
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION_COMPRESSOR']._serialized_start=2468
  _globals['_MONGOSCONFIG6_0_ENTERPRISE_NETWORK_COMPRESSION_COMPRESSOR']._serialized_end=2554
  _globals['_MONGODCONFIGSET6_0_ENTERPRISE']._serialized_start=4700
  _globals['_MONGODCONFIGSET6_0_ENTERPRISE']._serialized_end=4994
  _globals['_MONGOCFGCONFIGSET6_0_ENTERPRISE']._serialized_start=4997
  _globals['_MONGOCFGCONFIGSET6_0_ENTERPRISE']._serialized_end=5299
  _globals['_MONGOSCONFIGSET6_0_ENTERPRISE']._serialized_start=5302
  _globals['_MONGOSCONFIGSET6_0_ENTERPRISE']._serialized_end=5596
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.monitoring.v3.downsampling_pb2
import yandex.cloud.monitoring.v3.unit_format_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MultiSourceChartWidget(google.protobuf.message.Message):
    """Multi-source chart widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _FreezeDuration:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FreezeDurationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget._FreezeDuration.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FREEZE_DURATION_UNSPECIFIED: MultiSourceChartWidget._FreezeDuration.ValueType  # 0
        FREEZE_DURATION_HOUR: MultiSourceChartWidget._FreezeDuration.ValueType  # 1
        """Last hour."""
        FREEZE_DURATION_DAY: MultiSourceChartWidget._FreezeDuration.ValueType  # 2
        """Last day = last 24 hours."""
        FREEZE_DURATION_WEEK: MultiSourceChartWidget._FreezeDuration.ValueType  # 3
        """Last 7 days."""
        FREEZE_DURATION_MONTH: MultiSourceChartWidget._FreezeDuration.ValueType  # 4
        """Last 31 days."""

    class FreezeDuration(_FreezeDuration, metaclass=_FreezeDurationEnumTypeWrapper): ...
    FREEZE_DURATION_UNSPECIFIED: MultiSourceChartWidget.FreezeDuration.ValueType  # 0
    FREEZE_DURATION_HOUR: MultiSourceChartWidget.FreezeDuration.ValueType  # 1
    """Last hour."""
    FREEZE_DURATION_DAY: MultiSourceChartWidget.FreezeDuration.ValueType  # 2
    """Last day = last 24 hours."""
    FREEZE_DURATION_WEEK: MultiSourceChartWidget.FreezeDuration.ValueType  # 3
    """Last 7 days."""
    FREEZE_DURATION_MONTH: MultiSourceChartWidget.FreezeDuration.ValueType  # 4
    """Last 31 days."""

    @typing.final
    class Target(google.protobuf.message.Message):
        """Target settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class MonitoringTarget(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
            QUERY_FIELD_NUMBER: builtins.int
            TEXT_MODE_FIELD_NUMBER: builtins.int
            HIDDEN_FIELD_NUMBER: builtins.int
            NAME_FIELD_NUMBER: builtins.int
            data_source_id: builtins.str
            """Required. Data source ID."""
            query: builtins.str
            """Required. Query."""
            text_mode: builtins.bool
            """Text mode."""
            hidden: builtins.bool
            """Checks that target is visible or invisible."""
            name: builtins.str
            """Name of the query."""
            def __init__(
                self,
                *,
                data_source_id: builtins.str = ...,
                query: builtins.str = ...,
                text_mode: builtins.bool = ...,
                hidden: builtins.bool = ...,
                name: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["data_source_id", b"data_source_id", "hidden", b"hidden", "name", b"name", "query", b"query", "text_mode", b"text_mode"]) -> None: ...

        @typing.final
        class PrometheusTarget(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
            WORKSPACE_ID_FIELD_NUMBER: builtins.int
            QUERY_FIELD_NUMBER: builtins.int
            TEXT_MODE_FIELD_NUMBER: builtins.int
            HIDDEN_FIELD_NUMBER: builtins.int
            NAME_FIELD_NUMBER: builtins.int
            data_source_id: builtins.str
            """Required. Data source ID."""
            workspace_id: builtins.str
            """Required. Workspace ID."""
            query: builtins.str
            """Required. Query."""
            text_mode: builtins.bool
            """Text mode."""
            hidden: builtins.bool
            """Checks that target is visible or invisible."""
            name: builtins.str
            """Name of the query."""
            def __init__(
                self,
                *,
                data_source_id: builtins.str = ...,
                workspace_id: builtins.str = ...,
                query: builtins.str = ...,
                text_mode: builtins.bool = ...,
                hidden: builtins.bool = ...,
                name: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["data_source_id", b"data_source_id", "hidden", b"hidden", "name", b"name", "query", b"query", "text_mode", b"text_mode", "workspace_id", b"workspace_id"]) -> None: ...

        MONITORING_TARGET_FIELD_NUMBER: builtins.int
        PROMETHEUS_TARGET_FIELD_NUMBER: builtins.int
        @property
        def monitoring_target(self) -> global___MultiSourceChartWidget.Target.MonitoringTarget:
            """Monitoring target."""

        @property
        def prometheus_target(self) -> global___MultiSourceChartWidget.Target.PrometheusTarget:
            """Prometheus target."""

        def __init__(
            self,
            *,
            monitoring_target: global___MultiSourceChartWidget.Target.MonitoringTarget | None = ...,
            prometheus_target: global___MultiSourceChartWidget.Target.PrometheusTarget | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["monitoring_target", b"monitoring_target", "prometheus_target", b"prometheus_target", "target", b"target"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["monitoring_target", b"monitoring_target", "prometheus_target", b"prometheus_target", "target", b"target"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["monitoring_target", "prometheus_target"] | None: ...

    @typing.final
    class DataSource(google.protobuf.message.Message):
        """Data source settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class MonitoringDataSource(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ID_FIELD_NUMBER: builtins.int
            DOWNSAMPLING_FIELD_NUMBER: builtins.int
            id: builtins.str
            """Required. Data source ID."""
            @property
            def downsampling(self) -> yandex.cloud.monitoring.v3.downsampling_pb2.Downsampling:
                """Required. Downsampling settings."""

            def __init__(
                self,
                *,
                id: builtins.str = ...,
                downsampling: yandex.cloud.monitoring.v3.downsampling_pb2.Downsampling | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["downsampling", b"downsampling"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["downsampling", b"downsampling", "id", b"id"]) -> None: ...

        @typing.final
        class PrometheusDataSource(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ID_FIELD_NUMBER: builtins.int
            STEP_FIELD_NUMBER: builtins.int
            id: builtins.str
            """Required. Data source ID."""
            step: builtins.int
            """Required. Grid step in milliseconds."""
            def __init__(
                self,
                *,
                id: builtins.str = ...,
                step: builtins.int = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["id", b"id", "step", b"step"]) -> None: ...

        MONITORING_DATA_SOURCE_FIELD_NUMBER: builtins.int
        PROMETHEUS_DATA_SOURCE_FIELD_NUMBER: builtins.int
        @property
        def monitoring_data_source(self) -> global___MultiSourceChartWidget.DataSource.MonitoringDataSource:
            """Monitoring data source."""

        @property
        def prometheus_data_source(self) -> global___MultiSourceChartWidget.DataSource.PrometheusDataSource:
            """Prometheus data source."""

        def __init__(
            self,
            *,
            monitoring_data_source: global___MultiSourceChartWidget.DataSource.MonitoringDataSource | None = ...,
            prometheus_data_source: global___MultiSourceChartWidget.DataSource.PrometheusDataSource | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["data_source", b"data_source", "monitoring_data_source", b"monitoring_data_source", "prometheus_data_source", b"prometheus_data_source"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["data_source", b"data_source", "monitoring_data_source", b"monitoring_data_source", "prometheus_data_source", b"prometheus_data_source"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["data_source", b"data_source"]) -> typing.Literal["monitoring_data_source", "prometheus_data_source"] | None: ...

    @typing.final
    class VisualizationSettings(google.protobuf.message.Message):
        """Visualization settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _VisualizationType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _VisualizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            VISUALIZATION_TYPE_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 0
            """Not specified (line by default)."""
            VISUALIZATION_TYPE_LINE: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 1
            """Line chart."""
            VISUALIZATION_TYPE_STACK: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 2
            """Stack chart."""
            VISUALIZATION_TYPE_COLUMN: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 3
            """Points as columns chart."""
            VISUALIZATION_TYPE_POINTS: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 4
            """Points."""
            VISUALIZATION_TYPE_PIE: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 5
            """Pie aggregation chart."""
            VISUALIZATION_TYPE_BARS: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 6
            """Bars aggregation chart."""
            VISUALIZATION_TYPE_DISTRIBUTION: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 7
            """Distribution aggregation chart."""
            VISUALIZATION_TYPE_HEATMAP: MultiSourceChartWidget.VisualizationSettings._VisualizationType.ValueType  # 8
            """Heatmap aggregation chart."""

        class VisualizationType(_VisualizationType, metaclass=_VisualizationTypeEnumTypeWrapper):
            """Chart visualization type."""

        VISUALIZATION_TYPE_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 0
        """Not specified (line by default)."""
        VISUALIZATION_TYPE_LINE: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 1
        """Line chart."""
        VISUALIZATION_TYPE_STACK: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 2
        """Stack chart."""
        VISUALIZATION_TYPE_COLUMN: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 3
        """Points as columns chart."""
        VISUALIZATION_TYPE_POINTS: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 4
        """Points."""
        VISUALIZATION_TYPE_PIE: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 5
        """Pie aggregation chart."""
        VISUALIZATION_TYPE_BARS: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 6
        """Bars aggregation chart."""
        VISUALIZATION_TYPE_DISTRIBUTION: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 7
        """Distribution aggregation chart."""
        VISUALIZATION_TYPE_HEATMAP: MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType  # 8
        """Heatmap aggregation chart."""

        class _Interpolate:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _InterpolateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget.VisualizationSettings._Interpolate.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            INTERPOLATE_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings._Interpolate.ValueType  # 0
            """Not specified (linear by default)."""
            INTERPOLATE_LINEAR: MultiSourceChartWidget.VisualizationSettings._Interpolate.ValueType  # 1
            """Linear."""
            INTERPOLATE_LEFT: MultiSourceChartWidget.VisualizationSettings._Interpolate.ValueType  # 2
            """Left."""
            INTERPOLATE_RIGHT: MultiSourceChartWidget.VisualizationSettings._Interpolate.ValueType  # 3
            """Right."""

        class Interpolate(_Interpolate, metaclass=_InterpolateEnumTypeWrapper): ...
        INTERPOLATE_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings.Interpolate.ValueType  # 0
        """Not specified (linear by default)."""
        INTERPOLATE_LINEAR: MultiSourceChartWidget.VisualizationSettings.Interpolate.ValueType  # 1
        """Linear."""
        INTERPOLATE_LEFT: MultiSourceChartWidget.VisualizationSettings.Interpolate.ValueType  # 2
        """Left."""
        INTERPOLATE_RIGHT: MultiSourceChartWidget.VisualizationSettings.Interpolate.ValueType  # 3
        """Right."""

        class _YaxisType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _YaxisTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget.VisualizationSettings._YaxisType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            YAXIS_TYPE_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings._YaxisType.ValueType  # 0
            """Not specified (linear by default)."""
            YAXIS_TYPE_LINEAR: MultiSourceChartWidget.VisualizationSettings._YaxisType.ValueType  # 1
            """Linear."""
            YAXIS_TYPE_LOGARITHMIC: MultiSourceChartWidget.VisualizationSettings._YaxisType.ValueType  # 2
            """Logarithmic."""

        class YaxisType(_YaxisType, metaclass=_YaxisTypeEnumTypeWrapper):
            """Y axis type.
            N.B. _TYPE prefix is necessary to expect name clash with Interpolate LINEAR value.
            """

        YAXIS_TYPE_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings.YaxisType.ValueType  # 0
        """Not specified (linear by default)."""
        YAXIS_TYPE_LINEAR: MultiSourceChartWidget.VisualizationSettings.YaxisType.ValueType  # 1
        """Linear."""
        YAXIS_TYPE_LOGARITHMIC: MultiSourceChartWidget.VisualizationSettings.YaxisType.ValueType  # 2
        """Logarithmic."""

        class _SeriesAggregation:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SeriesAggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SERIES_AGGREGATION_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 0
            """Not specified (avg by default)."""
            SERIES_AGGREGATION_AVG: MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 1
            """Average."""
            SERIES_AGGREGATION_MIN: MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 2
            """Minimum."""
            SERIES_AGGREGATION_MAX: MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 3
            """Maximum."""
            SERIES_AGGREGATION_LAST: MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 4
            """Last non-NaN value."""
            SERIES_AGGREGATION_SUM: MultiSourceChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 5
            """Sum."""

        class SeriesAggregation(_SeriesAggregation, metaclass=_SeriesAggregationEnumTypeWrapper): ...
        SERIES_AGGREGATION_UNSPECIFIED: MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 0
        """Not specified (avg by default)."""
        SERIES_AGGREGATION_AVG: MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 1
        """Average."""
        SERIES_AGGREGATION_MIN: MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 2
        """Minimum."""
        SERIES_AGGREGATION_MAX: MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 3
        """Maximum."""
        SERIES_AGGREGATION_LAST: MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 4
        """Last non-NaN value."""
        SERIES_AGGREGATION_SUM: MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 5
        """Sum."""

        @typing.final
        class ColorSchemeSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class AutomaticColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class StandardColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class GradientColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                GREEN_VALUE_FIELD_NUMBER: builtins.int
                YELLOW_VALUE_FIELD_NUMBER: builtins.int
                RED_VALUE_FIELD_NUMBER: builtins.int
                VIOLET_VALUE_FIELD_NUMBER: builtins.int
                green_value: builtins.str
                """Gradient green value."""
                yellow_value: builtins.str
                """Gradient yellow value."""
                red_value: builtins.str
                """Gradient red value."""
                violet_value: builtins.str
                """Gradient violet_value."""
                def __init__(
                    self,
                    *,
                    green_value: builtins.str = ...,
                    yellow_value: builtins.str = ...,
                    red_value: builtins.str = ...,
                    violet_value: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["green_value", b"green_value", "red_value", b"red_value", "violet_value", b"violet_value", "yellow_value", b"yellow_value"]) -> None: ...

            @typing.final
            class HashColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            AUTOMATIC_FIELD_NUMBER: builtins.int
            STANDARD_FIELD_NUMBER: builtins.int
            GRADIENT_FIELD_NUMBER: builtins.int
            HASH_FIELD_NUMBER: builtins.int
            @property
            def automatic(self) -> global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme:
                """Automatic color scheme."""

            @property
            def standard(self) -> global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme:
                """Standard color scheme."""

            @property
            def gradient(self) -> global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme:
                """Gradient color scheme."""

            @property
            def hash(self) -> global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorScheme:
                """Hash color scheme. Based on line name or value."""

            def __init__(
                self,
                *,
                automatic: global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme | None = ...,
                standard: global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme | None = ...,
                gradient: global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme | None = ...,
                hash: global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorScheme | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["automatic", b"automatic", "gradient", b"gradient", "hash", b"hash", "scheme", b"scheme", "standard", b"standard"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["automatic", b"automatic", "gradient", b"gradient", "hash", b"hash", "scheme", b"scheme", "standard", b"standard"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["scheme", b"scheme"]) -> typing.Literal["automatic", "standard", "gradient", "hash"] | None: ...

        @typing.final
        class HeatmapSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            GREEN_VALUE_FIELD_NUMBER: builtins.int
            YELLOW_VALUE_FIELD_NUMBER: builtins.int
            RED_VALUE_FIELD_NUMBER: builtins.int
            VIOLET_VALUE_FIELD_NUMBER: builtins.int
            green_value: builtins.str
            """Heatmap green value."""
            yellow_value: builtins.str
            """Heatmap yellow value."""
            red_value: builtins.str
            """Heatmap red value."""
            violet_value: builtins.str
            """Heatmap violet_value."""
            def __init__(
                self,
                *,
                green_value: builtins.str = ...,
                yellow_value: builtins.str = ...,
                red_value: builtins.str = ...,
                violet_value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["green_value", b"green_value", "red_value", b"red_value", "violet_value", b"violet_value", "yellow_value", b"yellow_value"]) -> None: ...

        @typing.final
        class Yaxis(google.protobuf.message.Message):
            """Y axis settings."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TYPE_FIELD_NUMBER: builtins.int
            TITLE_FIELD_NUMBER: builtins.int
            MIN_FIELD_NUMBER: builtins.int
            MAX_FIELD_NUMBER: builtins.int
            UNIT_FORMAT_FIELD_NUMBER: builtins.int
            PRECISION_FIELD_NUMBER: builtins.int
            type: global___MultiSourceChartWidget.VisualizationSettings.YaxisType.ValueType
            """Type."""
            title: builtins.str
            """Title or empty."""
            min: builtins.str
            """Min value in extended number format or empty."""
            max: builtins.str
            """Max value in extended number format or empty."""
            unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType
            """Unit format."""
            @property
            def precision(self) -> google.protobuf.wrappers_pb2.Int64Value:
                """Tick value precision (null as default, 0-7 in other cases)."""

            def __init__(
                self,
                *,
                type: global___MultiSourceChartWidget.VisualizationSettings.YaxisType.ValueType = ...,
                title: builtins.str = ...,
                min: builtins.str = ...,
                max: builtins.str = ...,
                unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType = ...,
                precision: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["precision", b"precision"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["max", b"max", "min", b"min", "precision", b"precision", "title", b"title", "type", b"type", "unit_format", b"unit_format"]) -> None: ...

        @typing.final
        class YaxisSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            LEFT_FIELD_NUMBER: builtins.int
            RIGHT_FIELD_NUMBER: builtins.int
            @property
            def left(self) -> global___MultiSourceChartWidget.VisualizationSettings.Yaxis:
                """Left Y axis settings."""

            @property
            def right(self) -> global___MultiSourceChartWidget.VisualizationSettings.Yaxis:
                """Right Y axis settings."""

            def __init__(
                self,
                *,
                left: global___MultiSourceChartWidget.VisualizationSettings.Yaxis | None = ...,
                right: global___MultiSourceChartWidget.VisualizationSettings.Yaxis | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["left", b"left", "right", b"right"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["left", b"left", "right", b"right"]) -> None: ...

        TYPE_FIELD_NUMBER: builtins.int
        NORMALIZE_FIELD_NUMBER: builtins.int
        INTERPOLATE_FIELD_NUMBER: builtins.int
        AGGREGATION_FIELD_NUMBER: builtins.int
        COLOR_SCHEME_SETTINGS_FIELD_NUMBER: builtins.int
        HEATMAP_SETTINGS_FIELD_NUMBER: builtins.int
        YAXIS_SETTINGS_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        SHOW_LABELS_FIELD_NUMBER: builtins.int
        type: global___MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType
        """Visualization type."""
        normalize: builtins.bool
        """Normalize."""
        interpolate: global___MultiSourceChartWidget.VisualizationSettings.Interpolate.ValueType
        """Interpolate."""
        aggregation: global___MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType
        """Aggregation."""
        title: builtins.str
        """Inside chart title."""
        show_labels: builtins.bool
        """Show chart labels."""
        @property
        def color_scheme_settings(self) -> global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings:
            """Color scheme settings."""

        @property
        def heatmap_settings(self) -> global___MultiSourceChartWidget.VisualizationSettings.HeatmapSettings:
            """Heatmap settings."""

        @property
        def yaxis_settings(self) -> global___MultiSourceChartWidget.VisualizationSettings.YaxisSettings:
            """Y axis settings."""

        def __init__(
            self,
            *,
            type: global___MultiSourceChartWidget.VisualizationSettings.VisualizationType.ValueType = ...,
            normalize: builtins.bool = ...,
            interpolate: global___MultiSourceChartWidget.VisualizationSettings.Interpolate.ValueType = ...,
            aggregation: global___MultiSourceChartWidget.VisualizationSettings.SeriesAggregation.ValueType = ...,
            color_scheme_settings: global___MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings | None = ...,
            heatmap_settings: global___MultiSourceChartWidget.VisualizationSettings.HeatmapSettings | None = ...,
            yaxis_settings: global___MultiSourceChartWidget.VisualizationSettings.YaxisSettings | None = ...,
            title: builtins.str = ...,
            show_labels: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["color_scheme_settings", b"color_scheme_settings", "heatmap_settings", b"heatmap_settings", "yaxis_settings", b"yaxis_settings"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["aggregation", b"aggregation", "color_scheme_settings", b"color_scheme_settings", "heatmap_settings", b"heatmap_settings", "interpolate", b"interpolate", "normalize", b"normalize", "show_labels", b"show_labels", "title", b"title", "type", b"type", "yaxis_settings", b"yaxis_settings"]) -> None: ...

    @typing.final
    class SeriesOverrides(google.protobuf.message.Message):
        """Series override settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _YaxisPosition:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _YaxisPositionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget.SeriesOverrides._YaxisPosition.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            YAXIS_POSITION_UNSPECIFIED: MultiSourceChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 0
            """Not specified (left by default)."""
            YAXIS_POSITION_LEFT: MultiSourceChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 1
            """Left."""
            YAXIS_POSITION_RIGHT: MultiSourceChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 2
            """Right."""

        class YaxisPosition(_YaxisPosition, metaclass=_YaxisPositionEnumTypeWrapper): ...
        YAXIS_POSITION_UNSPECIFIED: MultiSourceChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 0
        """Not specified (left by default)."""
        YAXIS_POSITION_LEFT: MultiSourceChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 1
        """Left."""
        YAXIS_POSITION_RIGHT: MultiSourceChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 2
        """Right."""

        class _SeriesVisualizationType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SeriesVisualizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MultiSourceChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SERIES_VISUALIZATION_TYPE_UNSPECIFIED: MultiSourceChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 0
            """Not specified (line by default)."""
            SERIES_VISUALIZATION_TYPE_LINE: MultiSourceChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 1
            """Line chart."""
            SERIES_VISUALIZATION_TYPE_STACK: MultiSourceChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 2
            """Stack chart."""
            SERIES_VISUALIZATION_TYPE_COLUMN: MultiSourceChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 3
            """Points as columns chart."""
            SERIES_VISUALIZATION_TYPE_POINTS: MultiSourceChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 4
            """Points."""

        class SeriesVisualizationType(_SeriesVisualizationType, metaclass=_SeriesVisualizationTypeEnumTypeWrapper): ...
        SERIES_VISUALIZATION_TYPE_UNSPECIFIED: MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 0
        """Not specified (line by default)."""
        SERIES_VISUALIZATION_TYPE_LINE: MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 1
        """Line chart."""
        SERIES_VISUALIZATION_TYPE_STACK: MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 2
        """Stack chart."""
        SERIES_VISUALIZATION_TYPE_COLUMN: MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 3
        """Points as columns chart."""
        SERIES_VISUALIZATION_TYPE_POINTS: MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 4
        """Points."""

        @typing.final
        class SeriesOverrideSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            NAME_FIELD_NUMBER: builtins.int
            COLOR_FIELD_NUMBER: builtins.int
            TYPE_FIELD_NUMBER: builtins.int
            STACK_NAME_FIELD_NUMBER: builtins.int
            GROW_DOWN_FIELD_NUMBER: builtins.int
            YAXIS_POSITION_FIELD_NUMBER: builtins.int
            name: builtins.str
            """Series name or empty."""
            color: builtins.str
            """Series color or empty."""
            type: global___MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType
            """Type."""
            stack_name: builtins.str
            """Stack name or empty."""
            grow_down: builtins.bool
            """Stack grow down."""
            yaxis_position: global___MultiSourceChartWidget.SeriesOverrides.YaxisPosition.ValueType
            """Yaxis position."""
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                color: builtins.str = ...,
                type: global___MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType = ...,
                stack_name: builtins.str = ...,
                grow_down: builtins.bool = ...,
                yaxis_position: global___MultiSourceChartWidget.SeriesOverrides.YaxisPosition.ValueType = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["color", b"color", "grow_down", b"grow_down", "name", b"name", "stack_name", b"stack_name", "type", b"type", "yaxis_position", b"yaxis_position"]) -> None: ...

        NAME_FIELD_NUMBER: builtins.int
        TARGET_INDEX_FIELD_NUMBER: builtins.int
        SETTINGS_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Series name."""
        target_index: builtins.str
        """Target index."""
        @property
        def settings(self) -> global___MultiSourceChartWidget.SeriesOverrides.SeriesOverrideSettings:
            """Required. Override settings."""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            target_index: builtins.str = ...,
            settings: global___MultiSourceChartWidget.SeriesOverrides.SeriesOverrideSettings | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["name", b"name", "settings", b"settings", "target_index", b"target_index", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "settings", b"settings", "target_index", b"target_index", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["name", "target_index"] | None: ...

    @typing.final
    class NameHidingSettings(google.protobuf.message.Message):
        """Name hiding settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POSITIVE_FIELD_NUMBER: builtins.int
        NAMES_FIELD_NUMBER: builtins.int
        positive: builtins.bool
        """True if we want to show concrete series names only, false if we want to hide concrete series names."""
        @property
        def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Series names to show or hide."""

        def __init__(
            self,
            *,
            positive: builtins.bool = ...,
            names: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["names", b"names", "positive", b"positive"]) -> None: ...

    @typing.final
    class RepeatSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPEAT_BY_FIELD_NUMBER: builtins.int
        MAX_CHARTS_IN_ROW_FIELD_NUMBER: builtins.int
        max_charts_in_row: builtins.int
        """Max number of chart in one row."""
        @property
        def repeat_by(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Parameters to repeat by."""

        def __init__(
            self,
            *,
            repeat_by: collections.abc.Iterable[builtins.str] | None = ...,
            max_charts_in_row: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["max_charts_in_row", b"max_charts_in_row", "repeat_by", b"repeat_by"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    DATA_SOURCES_FIELD_NUMBER: builtins.int
    VISUALIZATION_SETTINGS_FIELD_NUMBER: builtins.int
    SERIES_OVERRIDES_FIELD_NUMBER: builtins.int
    NAME_HIDING_SETTINGS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DISPLAY_LEGEND_FIELD_NUMBER: builtins.int
    FREEZE_FIELD_NUMBER: builtins.int
    REPEAT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. Chart ID."""
    description: builtins.str
    """Chart description in dashboard (not enabled in UI)."""
    title: builtins.str
    """Chart widget title."""
    display_legend: builtins.bool
    """Enable legend under chart."""
    freeze: global___MultiSourceChartWidget.FreezeDuration.ValueType
    """Fixed time interval for chart."""
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiSourceChartWidget.Target]:
        """Targets."""

    @property
    def data_sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiSourceChartWidget.DataSource]:
        """Data sources."""

    @property
    def visualization_settings(self) -> global___MultiSourceChartWidget.VisualizationSettings:
        """Visualization settings."""

    @property
    def series_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiSourceChartWidget.SeriesOverrides]:
        """Override settings."""

    @property
    def name_hiding_settings(self) -> global___MultiSourceChartWidget.NameHidingSettings:
        """Name hiding settings."""

    @property
    def repeat(self) -> global___MultiSourceChartWidget.RepeatSettings:
        """Setting for repeat panel / repeat row"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        targets: collections.abc.Iterable[global___MultiSourceChartWidget.Target] | None = ...,
        data_sources: collections.abc.Iterable[global___MultiSourceChartWidget.DataSource] | None = ...,
        visualization_settings: global___MultiSourceChartWidget.VisualizationSettings | None = ...,
        series_overrides: collections.abc.Iterable[global___MultiSourceChartWidget.SeriesOverrides] | None = ...,
        name_hiding_settings: global___MultiSourceChartWidget.NameHidingSettings | None = ...,
        description: builtins.str = ...,
        title: builtins.str = ...,
        display_legend: builtins.bool = ...,
        freeze: global___MultiSourceChartWidget.FreezeDuration.ValueType = ...,
        repeat: global___MultiSourceChartWidget.RepeatSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name_hiding_settings", b"name_hiding_settings", "repeat", b"repeat", "visualization_settings", b"visualization_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_sources", b"data_sources", "description", b"description", "display_legend", b"display_legend", "freeze", b"freeze", "id", b"id", "name_hiding_settings", b"name_hiding_settings", "repeat", b"repeat", "series_overrides", b"series_overrides", "targets", b"targets", "title", b"title", "visualization_settings", b"visualization_settings"]) -> None: ...

global___MultiSourceChartWidget = MultiSourceChartWidget



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/image_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/image_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/containerregistry/v1/image_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a-yandex/cloud/containerregistry/v1/image.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"\xa4\x02\n\x11ListImagesRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\\\n\x0frepository_name\x18\x02 \x01(\tBC\xf2\xc7\x31?|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x12\x1b\n\tfolder_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x12ListImagesResponse\x12\x38\n\x06images\x18\x01 \x03(\x0b\x32(.yandex.cloud.containerregistry.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"1\n\x0fGetImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x12\x44\x65leteImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t2\x8a\x04\n\x0cImageService\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.containerregistry.v1.ListImagesRequest\x1a\x35.yandex.cloud.containerregistry.v1.ListImagesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/container-registry/v1/images\x12\x95\x01\n\x03Get\x12\x32.yandex.cloud.containerregistry.v1.GetImageRequest\x1a(.yandex.cloud.containerregistry.v1.Image\"0\x82\xd3\xe4\x93\x02*\x12(/container-registry/v1/images/{image_id}\x12\xc4\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.containerregistry.v1.DeleteImageRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*,\n\x13\x44\x65leteImageMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/container-registry/v1/images/{image_id}B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.image_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['repository_name']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['repository_name']._serialized_options = b'\362\3071?|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_GETIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_DELETEIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_IMAGESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/container-registry/v1/images'
  _globals['_IMAGESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/container-registry/v1/images/{image_id}'
  _globals['_IMAGESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteImageMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/container-registry/v1/images/{image_id}'
  _globals['_LISTIMAGESREQUEST']._serialized_start=275
  _globals['_LISTIMAGESREQUEST']._serialized_end=567
  _globals['_LISTIMAGESRESPONSE']._serialized_start=569
  _globals['_LISTIMAGESRESPONSE']._serialized_end=672
  _globals['_GETIMAGEREQUEST']._serialized_start=674
  _globals['_GETIMAGEREQUEST']._serialized_end=723
  _globals['_DELETEIMAGEREQUEST']._serialized_start=725
  _globals['_DELETEIMAGEREQUEST']._serialized_end=777
  _globals['_DELETEIMAGEMETADATA']._serialized_start=779
  _globals['_DELETEIMAGEMETADATA']._serialized_end=818
  _globals['_IMAGESERVICE']._serialized_start=821
  _globals['_IMAGESERVICE']._serialized_end=1343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/endpoint/parsers.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/endpoint/parsers.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/datatransfer/v1/endpoint/parsers.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\xfd\x02\n\x06Parser\x12Q\n\x0bjson_parser\x18\x01 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.GenericParserCommonH\x00\x12\\\n\x16\x61udit_trails_v1_parser\x18\x02 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.AuditTrailsV1ParserH\x00\x12Y\n\x14\x63loud_logging_parser\x18\x04 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.CloudLoggingParserH\x00\x12Q\n\x0btskv_parser\x18\x06 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.GenericParserCommonH\x00\x42\x08\n\x06parserJ\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06\"\xb7\x01\n\x13GenericParserCommon\x12\x46\n\x0b\x64\x61ta_schema\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.datatransfer.v1.endpoint.DataSchema\x12\x19\n\x11null_keys_allowed\x18\x02 \x01(\x08\x12\x17\n\x0f\x61\x64\x64_rest_column\x18\x03 \x01(\x08\x12\x1e\n\x16unescape_string_values\x18\x07 \x01(\x08J\x04\x08\x04\x10\x07\"\x15\n\x13\x41uditTrailsV1Parser\"\x14\n\x12\x43loudLoggingParserB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.parsers_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_PARSER']._serialized_start=147
  _globals['_PARSER']._serialized_end=528
  _globals['_GENERICPARSERCOMMON']._serialized_start=531
  _globals['_GENERICPARSERCOMMON']._serialized_end=714
  _globals['_AUDITTRAILSV1PARSER']._serialized_start=716
  _globals['_AUDITTRAILSV1PARSER']._serialized_end=737
  _globals['_CLOUDLOGGINGPARSER']._serialized_start=739
  _globals['_CLOUDLOGGINGPARSER']._serialized_end=759
# @@protoc_insertion_point(module_scope)
